/***************************************************************************
                           mainwindowoptionsimp.h
                             -------------------
    begin                : Tuesday Jan 10 2001
    copyright            : (C) 2001 Benjamin Meyer 
    email                : benjamin@csh.rit.edu
 ***************************************************************************/

#ifndef MAINWINDOWOPTIONSIMP_H
#define MAINWINDOWOPTIONSIMP_H

#include <mainwindowoptions.h>
#include <setup.h>

/**
  *@author Benjamin Meyer
  */

class MainWindowOptionsImp : public MainWindowOptions  {

Q_OBJECT
	
signals:
  void saveSettings();

public:
  MainWindowOptionsImp(QWidget *parent=0, const char *name=0);
  ~MainWindowOptionsImp();

public slots:
  void updateData();
  void getData();
  void changebuddylistOnlineFont();
  void changebuddylistOfflineFont();
  void changebuddylistSignOnFont();
  void setDefaultbuddylistOnlineFont();
  void setDefaultbuddylistOfflineFont();
  void setDefaultbuddylistSignOnFont();

private slots:
		
private:
  void updateFontSetting(QFont &f, QLabel *l);
  void updateLabel(QLabel *l, const QFont &f);
  settings_t *i_aimSettings;

};

#endif

// MainWindowOptionsImp.h

